<?php

/**
 * Simple caching of query results for Views displays.
 */
class max_age_cache extends views_plugin_cache_time {
  function options_form(&$form, &$form_state) {
    $options = array(60, 180, 300, 600, 900, 1800, 2700, 3600, 10800, 21600, 32400, 43200, 86400);
    $options = drupal_map_assoc($options, 'format_interval');
    $options = array(-1 => t('Never cache')) + $options;

    $form['results_lifespan'] = array(
      '#type' => 'select',
      '#title' => t('Query results'),
      '#description' => t('The length of time raw query results should be cached.'),
      '#options' => $options,
      '#default_value' => $this->options['results_lifespan'],
    );
    $form['output_lifespan'] = array(
      '#type' => 'select',
      '#title' => t('Rendered output'),
      '#description' => t('The length of time rendered HTML output should be cached.'),
      '#options' => $options,
      '#default_value' => $this->options['output_lifespan'],
    );
    $form['page_lifespan'] = array(
      '#type' => 'select',
      '#title' => t('Cached page'),
      '#description' => t('The length of time rendered page output should be cached by a reverse proxy. If there are several views on a page, the lowest value will be used.'),
      '#options' => $options,
      '#default_value' => $this->options['page_lifespan'],
    );
  }

  function cache_expire($type) {
    if (drupal_page_is_cacheable() && ($lifespan = $this->options['page_lifespan'])) {
      _max_age($lifespan);
    }
    if ($lifespan = $this->options[$type . '_lifespan']) {
      $cutoff = time() - $lifespan;
      return $cutoff;
    }
    else {
      return FALSE;
    }
  }

  function cache_set_expire($type) {
    if (drupal_page_is_cacheable() && ($lifespan = $this->options['page_lifespan'])) {
      _max_age($lifespan);
    }
    if ($lifespan = $this->options[$type . '_lifespan']) {
      return time() + $lifespan;
    }
    else {
      return CACHE_PERMANENT;
    }
  }

  function summary_title() {
    return format_interval($this->options['results_lifespan'], 1) . '/' . format_interval($this->options['output_lifespan'], 1)  . '/' . format_interval($this->options['page_lifespan'], 1);
  }
}
