<?php

/**
 * Simple caching of query results for Views displays.
 * Includes listening for changes/posts/deletions of
 * certain node types.
 */
class max_age_content_cache extends views_content_cache_plugin_cache {
  function option_definition() {
    $options = parent::option_definition();

    $options['page_lifespan'] = array('default' => 21600);

    return $options;
  }

  // We seem to need this for views 2
  function option_defaults(&$options) {
    $options['results_max_lifespan'] = 21600;
    $options['output_max_lifespan'] = 21600;
    $options['page_lifespan'] = 21600;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $options = array(60, 300, 1800, 3600, 21600, 518400);
    $options = drupal_map_assoc($options, 'format_interval');
    $max_options = array(-1 => t('None')) + $options + array(-2 => t('Never cache'));

    $form['page_lifespan'] = array(
      '#type' => 'select',
      '#title' => t('Page output - Max age cache header'),
      '#description' => t("Which cache header to set. We'll set the selected max age header. If another such header is set on a given page, the lower value wins."),
      '#options' => $max_options,
      '#default_value' => $this->options['page_lifespan'],
    );
  }

  function summary_title() {
    return "Content cache (max age)";
  }

   /**
    * Determine expiration time in the cache table of the cache type
    * or CACHE_PERMANENT if item shouldn't be removed automatically from cache.
    *
    * Plugins must override this to implement expiration in the cache table.
    *
    * @param $type
    *   The cache type, either 'query', 'result' or 'output'.
    */
  function cache_set_expire($type) {
    if (drupal_page_is_cacheable() && ($lifespan = $this->options['page_lifespan'])) {
      _max_age($lifespan);
    }
    return CACHE_PERMANENT;
  }

  /**
   * Return the expiry time for this cache plugin.
   *
   * This should be the last time that the content has changed, altered to allow
   * for the the min/max lifetimes.
   */
  function cache_expire($type) {
    if (drupal_page_is_cacheable() && ($lifespan = $this->options['page_lifespan'])) {
      _max_age($lifespan);
    }

    return parent::cache_expire($type);
  }
}
